==> faiadashu-0.2.2.tar.gz: lib/questionnaires/view/item/questionnaire_answer_filler_factory.dart <==
import 'package:fhir/r4.dart';
import 'package:flutter/material.dart';

import '../../../faiadashu.dart';
import '../../model/questionnaire_location.dart';
import '../broken_questionnaire_item.dart';
import 'answer/answer.dart';
import 'item.dart';

// ignore: avoid_classes_with_only_static_members
class QuestionnaireAnswerFillerFactory {
  static final _logger = Logger(QuestionnaireAnswerFillerFactory);

  static QuestionnaireAnswerFiller fromQuestionnaireItem(
      QuestionnaireLocation location, AnswerLocation answerLocation) {
    _logger.debug('Creating AnswerFiller for $location');

    try {
      switch (location.questionnaireItem.type!) {
        case QuestionnaireItemType.choice:
        case QuestionnaireItemType.open_choice:
          return CodingAnswer(location, answerLocation);
        case QuestionnaireItemType.quantity:
        case QuestionnaireItemType.decimal:
        case QuestionnaireItemType.integer:
          return (location.isCalculatedExpression)
              ? StaticItem(location, answerLocation)
              : NumericalAnswer(location, answerLocation);
        case QuestionnaireItemType.string:
        case QuestionnaireItemType.text:
        case QuestionnaireItemType.url:
          return StringAnswer(location, answerLocation);
        case QuestionnaireItemType.display:
        case QuestionnaireItemType.group:
          return StaticItem(location, answerLocation);
        case QuestionnaireItemType.date:
        case QuestionnaireItemType.datetime:
        case QuestionnaireItemType.time:
          return DateTimeAnswer(location, answerLocation);
        case QuestionnaireItemType.boolean:
          return BooleanAnswer(location, answerLocation);
        case QuestionnaireItemType.attachment:
        case QuestionnaireItemType.unknown:
        case QuestionnaireItemType.reference:
          throw QuestionnaireFormatException(
              'Unsupported item type: ${location.questionnaireItem.type!}');
      }
    } catch (exception) {
      _logger.warn('Cannot create answer filler:', error: exception);
      return _BrokenItem(location, answerLocation, exception);
    }
  }
}

class _BrokenItem extends QuestionnaireAnswerFiller {
  final Object exception;

  const _BrokenItem(QuestionnaireLocation location,
      AnswerLocation answerLocation, this.exception)
      : super(location, answerLocation);

  @override
  State<StatefulWidget> createState() => _BrokenItemState();
}

class _BrokenItemState extends State<_BrokenItem> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return BrokenQuestionnaireItem(
        'Could not initialize QuestionnaireAnswerFiller',
        widget.location.questionnaireItem,
        widget.exception);
  }
}

==> faiadashu-0.2.5.tar.gz: lib/questionnaires/view/item/questionnaire_answer_filler_factory.dart <==
import 'package:fhir/r4.dart';
import 'package:flutter/material.dart';

import '../../../faiadashu.dart';
import '../../model/questionnaire_location.dart';
import '../broken_questionnaire_item.dart';
import 'answer/answer.dart';
import 'item.dart';

// ignore: avoid_classes_with_only_static_members
class QuestionnaireAnswerFillerFactory {
  static final _logger = Logger(QuestionnaireAnswerFillerFactory);

  static QuestionnaireAnswerFiller fromQuestionnaireItem(
      QuestionnaireLocation location, AnswerLocation answerLocation) {
    _logger.debug('Creating AnswerFiller for $location');

    try {
      switch (location.questionnaireItem.type!) {
        case QuestionnaireItemType.choice:
        case QuestionnaireItemType.open_choice:
          return CodingAnswerFiller(location, answerLocation);
        case QuestionnaireItemType.quantity:
        case QuestionnaireItemType.decimal:
        case QuestionnaireItemType.integer:
          return (location.isCalculatedExpression)
              ? StaticItem(location, answerLocation)
              : NumericalAnswerFiller(location, answerLocation);
        case QuestionnaireItemType.string:
        case QuestionnaireItemType.text:
        case QuestionnaireItemType.url:
          return StringAnswerFiller(location, answerLocation);
        case QuestionnaireItemType.display:
        case QuestionnaireItemType.group:
          return StaticItem(location, answerLocation);
        case QuestionnaireItemType.date:
        case QuestionnaireItemType.datetime:
        case QuestionnaireItemType.time:
          return DateTimeAnswerFiller(location, answerLocation);
        case QuestionnaireItemType.boolean:
          return BooleanAnswerFiller(location, answerLocation);
        case QuestionnaireItemType.attachment:
        case QuestionnaireItemType.unknown:
        case QuestionnaireItemType.reference:
          throw QuestionnaireFormatException(
              'Unsupported item type: ${location.questionnaireItem.type!}');
      }
    } catch (exception) {
      _logger.warn('Cannot create answer filler:', error: exception);
      return _BrokenItem(location, answerLocation, exception);
    }
  }
}

class _BrokenItem extends QuestionnaireAnswerFiller {
  final Object exception;

  const _BrokenItem(QuestionnaireLocation location,
      AnswerLocation answerLocation, this.exception)
      : super(location, answerLocation);

  @override
  State<StatefulWidget> createState() => _BrokenItemState();
}

class _BrokenItemState extends State<_BrokenItem> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return BrokenQuestionnaireItem(
        'Could not initialize QuestionnaireAnswerFiller',
        widget.location.questionnaireItem,
        widget.exception);
  }
}
